==> XoopsHP1.1.zip: XoopsHP1.1/module/XoopsHP/blocks/xhp_block_completed.php <==
<?php
// $Id: xhp_block_completed.php,v 1.07 2007/08/07 23:47:52 Yoshi Exp $
//  ------------------------------------------------------------------------ //
//                XOOPS - PHP Content Management System                      //
//                    Copyright (c) 2000 XOOPS.org                           //
//                       <http://www.xoops.org/>                             //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

// Variables
// $options[0]: sorting order <DESC or ''> //
// $options[1]: num to list //
// $options[2]: min num to list //
// $options[3]: module dirname //

function b_xhp_completed_show($options) {
	global $xoopsDB, $xoopsUser, $xoopsConfig;
	$myts =& MyTextSanitizer::getInstance();
	$block = array();
	$mydirname = $options[3];
	$mymodpath = "modules/$mydirname" ;
	include "$mymodpath/module_prefix.php";
	$rsl = $xoopsDB->prefix( $module_prefix."_results" ) ;
	$usr = $xoopsDB->prefix( "users" ) ;
	$sql = "SELECT count(*) AS completed, $rsl.uid, $usr.uname FROM $rsl INNER JOIN $usr ON $rsl.uid=$usr.uid GROUP BY $rsl.uid HAVING completed >= $options[2] ORDER BY completed $options[0] LIMIT $options[1]";
	$result = $xoopsDB->query($sql);
	while ( $myrow = $xoopsDB->fetchArray($result) ) {
		$items = array();
		$items['completed'] = $myrow['completed'];
		$items['uname'] = $myrow['uname'];
		$items['uid'] = $myrow['uid'];
		$block['items'][] = $items;
	}
	return $block;
}

function b_xhp_completed_edit($options) {
	$form = _MB_ITEMS_ORDER."&nbsp;<select name='options[]'>";
	$form .= "<option value='DESC'";
	if ( $options[0] == "DESC" ) {
		$form .= " selected='selected'";
	}
	$form .= ">"._MB_ITEMS_DESC."</option>\n";
	$form .= "<option value=''";
	if($options[0] == ""){
		$form .= " selected='selected'";
	}
	$form .= ">"._MB_ITEMS_ASCEND."</option>\n";
	$form .= "</select>\n";
	$form .= "&nbsp;"._MB_ITEMS_DISP."&nbsp;<input type='text'  size=5 name='options[]' value='".$options[1]."' />&nbsp;"._MB_ITEMS_ARTCLS."<br>\n";
	$form .= "&nbsp;"._MB_MINIMUM."&nbsp;<input type='text'  size=5 name='options[]' value='".$options[2]."' />&nbsp; "._MB_ITEMS_ARTCLS;
	$form .= "<input type='hidden' name='options[]' value='".$options[3]."'>";


	return $form;
}
?>

==> XoopsHP1.11.zip: XoopsHP1.11/module/XoopsHP/blocks/xhp_block_completed.php <==
<?php
// $Id: xhp_block_completed.php,v 1.07 2007/08/07 23:47:52 Yoshi Exp $
//  ------------------------------------------------------------------------ //
//                XOOPS - PHP Content Management System                      //
//                    Copyright (c) 2000 XOOPS.org                           //
//                       <http://www.xoops.org/>                             //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

// Variables
// $options[0]: sorting order <DESC or ''> //
// $options[1]: num to list //
// $options[2]: min num to list //
// $options[3]: module dirname //

function b_XHP_completed_show($options) {
	global $xoopsDB, $xoopsUser, $xoopsConfig;
	$myts =& MyTextSanitizer::getInstance();
	$block = array();
	$mydirname = $options[3];
	$mymodpath = "modules/$mydirname" ;
	include "$mymodpath/module_prefix.php";
	$rsl = $xoopsDB->prefix( $module_prefix."_results" ) ;
	$usr = $xoopsDB->prefix( "users" ) ;
	$sql = "SELECT count(*) AS completed, $rsl.uid, $usr.uname FROM $rsl INNER JOIN $usr ON $rsl.uid=$usr.uid GROUP BY $rsl.uid HAVING completed >= $options[2] ORDER BY completed $options[0] LIMIT $options[1]";
	$result = $xoopsDB->query($sql);
	while ( $myrow = $xoopsDB->fetchArray($result) ) {
		$items = array();
		$items['completed'] = $myrow['completed'];
		$items['uname'] = $myrow['uname'];
		$items['uid'] = $myrow['uid'];
		$block['items'][] = $items;
	}
	return $block;
}

function b_XHP_completed_edit($options) {
	$form = _MB_XHP_ITEMS_ORDER."&nbsp;<select name='options[]'>";
	$form .= "<option value='DESC'";
	if ( $options[0] == "DESC" ) {
		$form .= " selected='selected'";
	}
	$form .= ">"._MB_XHP_ITEMS_DESC."</option>\n";
	$form .= "<option value=''";
	if($options[0] == ""){
		$form .= " selected='selected'";
	}
	$form .= ">"._MB_XHP_ITEMS_ASCEND."</option>\n";
	$form .= "</select>\n";
	$form .= "&nbsp;"._MB_XHP_ITEMS_DISP."&nbsp;<input type='text'  size=5 name='options[]' value='".$options[1]."' />&nbsp;"._MB_XHP_ITEMS_ARTCLS."<br>\n";
	$form .= "&nbsp;"._MB_XHP_MINIMUM."&nbsp;<input type='text'  size=5 name='options[]' value='".$options[2]."' />&nbsp; "._MB_XHP_ITEMS_ARTCLS;
	$form .= "<input type='hidden' name='options[]' value='".$options[3]."'>";


	return $form;
}
?>
